@@ -4,18 +4,20 @@ use strict;
 use warnings;
 
 use Carp;
+use Const::Fast;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
 use Hash::MultiValue;
 use HTTP::Response;
 use HTTP::Tiny;
-use Moose::Util::TypeConstraints;
+use Moose::Util::TypeConstraints qw(find_type_constraint);
 use Params::ValidationCompiler qw( validation_for );
+use Test::BDD::Cucumber::Definitions::TypeConstraints;
 use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our @EXPORT_OK = qw(
     S C
@@ -35,10 +37,14 @@ our %EXPORT_TAGS = (
     ]
 );
 
-## no critic [Subroutines::RequireArgUnpacking]
-
 my $http = HTTP::Tiny->new();
 
+# Exceptions will result in a pseudo-HTTP status code of 599 and a reason of "Internal Exception".
+# The content field in the response will contain the text of the exception.
+const my $HTTP_INTERNAL_EXCEPTION => 599;
+
+## no critic [Subroutines::RequireArgUnpacking]
+
 sub S { return Test::BDD::Cucumber::StepFile::S }
 sub C { return Test::BDD::Cucumber::StepFile::C }
 
@@ -46,18 +52,10 @@ my $validator_header_set = validation_for(
     params => [
 
         # http request header name
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid string}}
-            ),
-        },
+        { type => find_type_constraint('ValueString') },
 
         # http request header value
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid string}}
-            ),
-        }
+        { type => find_type_constraint('ValueString') },
     ]
 );
 
@@ -73,11 +71,7 @@ my $validator_content_set = validation_for(
     params => [
 
         # http request content
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid string}}
-            ),
-        }
+        { type => find_type_constraint('ValueString') },
     ]
 );
 
@@ -93,14 +87,10 @@ my $validator_request_send = validation_for(
     params => [
 
         # http request method
-        { type => enum( [qw(GET HEAD POST PUT DELETE CONNECT OPTIONS TRACE PATCH)] ) },
+        { type => find_type_constraint('ValueString') },
 
         # http request url
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid string}}
-            ),
-        }
+        { type => find_type_constraint('ValueString') },
     ]
 );
 
@@ -118,10 +108,8 @@ sub request_send {
 
     S->{http}->{response} = $http->request( $method, $url, $options );
 
-    # Exceptions will result in a pseudo-HTTP status code of 599 and a reason of "Internal Exception".
-    # The content field in the response will contain the text of the exception.
-    if ( S->{http}->{response}->{status} == 599 ) {
-        fail(qq{Http request was sent});
+    if ( S->{http}->{response}->{status} == $HTTP_INTERNAL_EXCEPTION ) {
+        fail('Http request was sent');
         diag( S->{http}->{response}->{content} );
     }
 
@@ -147,11 +135,7 @@ my $validator_code_eq = validation_for(
     params => [
 
         # http response code
-        {   type => subtype(
-                as 'Int',
-                message {qq{"$_" is not a valid integer}}
-            ),
-        }
+        { type => find_type_constraint('ValueInteger') },
     ]
 );
 
@@ -160,8 +144,7 @@ sub code_eq {
 
     is( S->{http}->{response}->{status}, $code, qq{Http response code eq "$code"} );
 
-    diag(
-        sprintf( 'Http response status = "%s %s"', S->{http}->{response}->{status}, S->{http}->{response}->{reason} ) );
+    diag( sprintf 'Http response status = "%s %s"', S->{http}->{response}->{status}, S->{http}->{response}->{reason} );
 
     return;
 }
@@ -170,18 +153,10 @@ my $validator_header_eq = validation_for(
     params => [
 
         # http response header name
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid http response header name}}
-            ),
-        },
+        { type => find_type_constraint('ValueString') },
 
         # http response header value
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid string}}
-            ),
-        }
+        { type => find_type_constraint('ValueString') },
 
     ]
 );
@@ -200,30 +175,18 @@ my $validator_header_re = validation_for(
     params => [
 
         # http response header name
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid http response header name}}
-            ),
-        },
+        { type => find_type_constraint('ValueString') },
 
         # http response header value
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid regular expression}}
-            ),
-        }
-
+        { type => find_type_constraint('ValueRegexp') }
     ]
 );
 
 sub header_re {
+
     my ( $header, $value ) = $validator_header_re->(@_);
 
-    like(
-        S->{http}->{response}->{headers}->{ lc $header },
-        qr/$value/,    ## no critic [RegularExpressions::RequireExtendedFormatting]
-        qq{Http response header "$header" re "$value"}
-    );
+    like( S->{http}->{response}->{headers}->{ lc $header }, $value, qq{Http response header "$header" re "$value"} );
 
     diag( 'Http response headers = ' . np S->{http}->{response}->{headers} );
 
@@ -234,11 +197,8 @@ my $validator_content_eq = validation_for(
     params => [
 
         # http response content
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid string}}
-            ),
-        }
+        { type => find_type_constraint('ValueString') },
+
     ]
 );
 
@@ -265,22 +225,14 @@ my $validator_content_re = validation_for(
     params => [
 
         # http response content
-        {   type => subtype(
-                as 'Str',
-                message {qq{"$_" is not a valid regular expression}}
-            ),
-        }
+        { type => find_type_constraint('ValueRegexp') }
     ]
 );
 
 sub content_re {
     my ($content) = $validator_content_re->(@_);
 
-    like(
-        S->{http}->{response}->{content},
-        qr/$content/,    ## no critic [RegularExpressions::RequireExtendedFormatting]
-        qq{Http response content re "$content"}
-    );
+    like( S->{http}->{response}->{content}, $content, qq{Http response content re "$content"} );
 
     return;
 }
@@ -288,11 +240,7 @@ sub content_re {
 sub content_re_decoded {
     my ($content) = $validator_content_re->(@_);
 
-    like(
-        S->{http}->{response_object}->decoded_content(),
-        qr/$content/,    ## no critic [RegularExpressions::RequireExtendedFormatting]
-        qq{Http response decoded content re "$content"}
-    );
+    like( S->{http}->{response_object}->decoded_content(), $content, qq{Http response decoded content re "$content"} );
 
     diag( 'Http response content type = ' . np S->{http}->{response_object}->headers->content_type );
     diag( 'Http response content charset = ' . np S->{http}->{response_object}->headers->content_type_charset );
